@@ -17,6 +17,7 @@ from strenum import LowercaseStrEnum
 from nef_pipelines.lib import util
 from nef_pipelines.lib.constants import NEF_PIPELINES
 from nef_pipelines.lib.globals_lib import set_global
+from nef_pipelines.lib.structures import NEFPipelinesException
 from nef_pipelines.lib.util import (
     exit_error,
     fixup_metadata,
@@ -62,6 +63,26 @@ class NoSuchColumnException(Exception):
     pass
 
 
+class NEFPLSLIOException(NEFPipelinesException):
+    """Exception for NEF Pipelines IO errors with optional chaining."""
+
+    def __init__(self, message: str, chained_exception: Optional[Exception] = None):
+        super().__init__(message)
+        self.__cause__ = chained_exception
+
+
+class NEFPLSLIOEmptyStdinException(NEFPLSLIOException):
+    """Exception for empty stdin when reading NEF data."""
+
+    pass
+
+
+class NEFPLSLIOStarParseException(NEFPLSLIOException):
+    """Exception for NEF/STAR parsing errors."""
+
+    pass
+
+
 # what the selection type is for Star SaveFrames
 class SelectionType(LowercaseStrEnum):
     NAME = auto()
@@ -259,6 +280,45 @@ def read_file_or_exit(file_path: Path) -> List[str]:
     return result
 
 
+# refactor to two functions one of which gets a TextIO
+def read_entry_from_stdin_or_raise() -> Entry:
+    """
+    read a star file entry from stdin or exit with an error message
+    :return: a star file entry
+    """
+
+    if sys.stdin.isatty():
+        raise NEFPLSLIOEmptyStdinException(
+            "you appear to be reading from an empty stdin"
+        )
+
+    try:
+        stdin_lines = sys.stdin.read()
+        if stdin_lines is None:
+            lines = [
+                "",
+            ]
+        lines = "".join(stdin_lines)
+    except IOError as e:
+        raise NEFPLSLIOException(f"failed to read stdin because: {e}", e)
+
+    if len(lines.strip()) == 0:
+        raise NEFPLSLIOEmptyStdinException(
+            "stdin is empty and doesn't contain a NEF file"
+        )
+
+    try:
+        entry = Entry.from_string(lines)
+
+    except ParsingError as e:
+        msg = f"failed to read a NEF entry from stdin because the NEF parser found the following error: {e}"
+        raise NEFPLSLIOStarParseException(msg, e)
+
+    entry.source = "-"
+
+    return entry
+
+
 # refactor to two functions one of which gets a TextIO
 def read_entry_from_stdin_or_exit() -> Entry:
     """
@@ -469,6 +529,21 @@ def select_frames(
     return list(result.values()) if result else []
 
 
+def read_entry_from_file_or_stdin_or_raise(file: Path) -> Entry:
+    """
+    read a star entry from stdin or a file or exit.
+    note this exits with an error if stdin can't be read because its a terminal
+
+    :param file:
+    :return:
+    """
+    if file is None or file == Path("-"):
+        entry = read_entry_from_stdin_or_raise()
+    else:
+        entry = read_entry_from_file_or_raise(file)
+    return entry
+
+
 def read_entry_from_file_or_stdin_or_exit_error(file: Path) -> Entry:
     """
     read a star entry from stdin or a file or exit.
@@ -484,6 +559,22 @@ def read_entry_from_file_or_stdin_or_exit_error(file: Path) -> Entry:
     return entry
 
 
+def read_entry_from_file_or_raise(file):
+    """
+    read a star entry from a file
+
+    :param file: a file on the file system
+    :return: a new Entry read from the file
+    :raises: IOError if the file doesn't exist, isn't a file, or can't be read
+    """
+    file = Path(file)
+
+    with open(file) as fh:
+        entry = Entry.from_file(fh)
+
+    return entry
+
+
 def read_entry_from_file_or_exit_error(file):
     """
     read a star entry from a file or exit with an error message
@@ -491,19 +582,10 @@ def read_entry_from_file_or_exit_error(file):
     :param file: a file on the file system
     :return: a new Entry read from the file
     """
-
-    file = Path(file)
-
-    if not file.exists() or not file.is_file():
-        exit_error(f"the file {file} doesn't exist or isn't a file")
     try:
-        with open(file) as fh:
-            entry = Entry.from_file(fh)
-
+        return read_entry_from_file_or_raise(file)
     except IOError as e:
-        exit_error(f"couldn't read from the file {file}", e)
-
-    return entry
+        exit_error(f"couldn't read an entry from the file {file} because {e}")
 
 
 # TODO: should be used as underpinnings for other related functions here
@@ -622,7 +704,9 @@ def molecular_system_from_entry(entry):
     return result
 
 
-def add_frames_to_entry(entry: Entry, frames: List[Saveframe]) -> Entry:
+def add_frames_to_entry(
+    entry: Entry, frames: Union[List[Saveframe], Saveframe]
+) -> Entry:
     # TODO deal with merging esp wrt to molecular systems and possibly with other information
     # TODO add frame rename and frame delete
     """
@@ -630,13 +714,18 @@ def add_frames_to_entry(entry: Entry, frames: List[Saveframe]) -> Entry:
 
     Args:
         entry: an entry to add the save frames to
-        frames: a set of save frames to add, they must have different names to those present already
+        frames: a set of save frames or a frame to add, they must have different names to those present already
 
 
     Returns:
         the updated entry containing the frames
     """
 
+    if isinstance(frames, Saveframe):
+        frames = [
+            frames,
+        ]
+
     fixup_metadata(entry, NEF_PIPELINES, get_version(), script_name(__file__))
 
     for frame in frames:
