@@ -26,6 +26,7 @@ from typing import (
 )
 
 import click
+import typer
 from pynmrstar import Entry, Loop, Saveframe
 from strenum import StrEnum
 from tabulate import tabulate
@@ -368,6 +369,9 @@ def exit_error(msg, exception=None):
         msg: the message
     """
 
+    # this has to be imported after complete initialisation has occured and after this module has been initialised...
+    from nef_pipelines.main import debug_mode
+
     # This should only happen in verbose mode
     if exception is not None:
         exc_info = sys.exc_info()
@@ -382,12 +386,22 @@ def exit_error(msg, exception=None):
 
     command = _script_to_command(script)
 
+    if debug_mode:
+        print(file=sys.stderr)
+        print("----------- traceback -----------", file=sys.stderr)
+        print(traceback.print_stack(), file=sys.stderr)
+        print("---------------------------------", file=sys.stderr)
+        print(file=sys.stderr)
+
     print(f"ERROR [in: {command}]: {msg[0]}", file=sys.stderr)
-    print(file=sys.stderr)
-    print("----------- traceback -----------", file=sys.stderr)
-    print(traceback.print_stack(), file=sys.stderr)
-    print("---------------------------------", file=sys.stderr)
-    print(file=sys.stderr)
+
+    if debug_mode:
+
+        sys_argv = " ".join(sys.argv[1:])
+        debug_clause = f"... for full debug information run: nef --debug {sys_argv}"
+
+        print(file=sys.stderr)
+        print(debug_clause, file=sys.stderr)
 
     for line in msg[1:]:
         print(f"  {line}", file=sys.stderr)
@@ -398,10 +412,36 @@ def exit_error(msg, exception=None):
     sys.exit(EXIT_ERROR)
 
 
-def warn(msg):
-    """print a warning to stderr prefixed with WARNING:"""
+def warn(msg=None):
+    """print a warning to stderr prefixed with WARNING:
+
+    - note empty lines do not have info prepended
+    """
     msg = dedent(msg)
-    print(f"WARNING: {msg}", file=sys.stderr)
+    msg = msg.strip()
+    if msg:
+        print(f"WARNING: {msg}", file=sys.stderr)
+    else:
+        print(file=sys.stderr)
+
+
+def info(msg=None, verbose=True):
+    """
+    print information to stderr prefixed with INFO:
+
+    msg: the msg to print
+    verbose: only output the message if verbose is true
+
+    - note empty lines do not have info prepended
+    """
+
+    if verbose:
+        msg = dedent(msg)
+        msg = msg.strip()
+        if msg:
+            print(f"INFO: {msg}", file=sys.stderr)
+        else:
+            print(file=sys.stderr)
 
 
 def process_stream_and_add_frames(
@@ -612,6 +652,10 @@ def parse_comma_separated_options(
     :param lists: a mixture of  lists of string or comma separated as a at sting
     :return: list of items
     """
+
+    if lists is None:
+        lists = []
+
     result = []
     for item in lists:
         if isinstance(item, str):
@@ -1051,3 +1095,59 @@ def file_exists_and_has_bytes(output_file: Path):
         and output_file.is_file()
         and output_file.stat().st_size != 0
     )
+
+
+def expand_template_or_exit_error(template: str, **variables: Any) -> str:
+    """
+    Apply template variable substitution with error handling.
+
+    This function performs string template substitution using Python's str.format() method,
+    and calls exit_error with anl error message if invalid template variables are used.
+
+    Args:
+        template: Template string with {variable} placeholders (e.g., "file_{name}_{type}")
+        **variables: Available variables for substitution as keyword arguments
+
+    Returns:
+        Formatted string with variables substituted
+
+    Raises:
+        Calls exit_error if template contains invalid variables, providing:
+        - The invalid variable name
+        - The original template string
+        - List of available variables
+
+    Example:
+        >>> expand_template_or_exit_error("output_{name}_{type}", name="data", type="csv")
+        'output_data_csv'
+
+        >>> expand_template_or_exit_error("bad_{invalid}", name="test")
+        # Calls exit_error with helpful message about 'invalid' variable
+    """
+    try:
+        return template.format(**variables)
+    except KeyError as e:
+        # Extract the invalid variable name from the exception
+        invalid_var = str(e).strip("'\"")
+
+        # Get available variables for the error message
+        available_vars = ", ".join(sorted(variables.keys()))
+
+        exit_error(
+            f"invalid template variable '{invalid_var}' in template '{template}'. "
+            f"Available variables are: {available_vars}"
+        )
+
+
+def display_help_and_exit(context: click.Context, msg: Optional[str] = None):
+    """
+    Display the help text for the program and exit without error
+
+    Args:
+        context (click.Context): typer/click context
+        msg (Optional[str]): optional message to display in red after help text
+    """
+    typer.echo(context.get_help())
+    if msg:
+        typer.echo(typer.style(msg, fg=typer.colors.BRIGHT_RED, bold=True))
+    sys.exit(0)
