@@ -17,21 +17,14 @@ from nef_pipelines.tools.fit.fit_lib import (
     _fit_results_as_frame,
     _select_relaxation_series_or_exit,
     _series_frame_to_id_series_data,
+    calculate_noise_level_from_replicates,
 )
 
 try:
-    from streamfitter import LoggingLevels, fitter
-    from streamfitter.error_propogation import ErrorPropogation
+    from nef_pipelines.lib.interface import LoggingLevels, NoiseInfo, NoiseInfoSource
 
 except ImportError as e:
-    from enum import IntEnum, auto
-
-    from strenum import StrEnum
-
-    class ErrorPropogation(StrEnum):
-        PROPOGATION = auto()
-        JACKNIFE = auto()
-        BOOTSTRAP = auto()
+    from enum import IntEnum
 
     class LoggingLevels(IntEnum):
         WARNING = 0
@@ -39,11 +32,11 @@ except ImportError as e:
         DEBUG = 2
         ALL = 3
 
-    fitter = None
     stream_fitter_import_error = str(e)
 
-VERBOSE_HELP = \
-"""how verbose to be, each call of verbose increases the verbosity, note this currently only reports JAX warnings"""
+VERBOSE_HELP = """
+    how verbose to be, each call of verbose increases the verbosity, note this currently only reports JAX warnings
+    """
 
 
 @fit_app.command()
@@ -55,12 +48,6 @@ def exponential(
         metavar="NEF-FILE",
         help="read NEF data from a file instead of stdin",
     ),
-    error_method: ErrorPropogation = typer.Option(
-        ErrorPropogation.PROPOGATION,
-        "-e",
-        "--error-method",
-        help="error propagation method",
-    ),
     cycles: int = typer.Option(
         1000,
         "-c",
@@ -104,7 +91,6 @@ def exponential(
     entry = pipe(
         entry,
         series_frames,
-        error_method,
         cycles,
         noise_level,
         data_type,
@@ -118,7 +104,6 @@ def exponential(
 def pipe(
     entry: Entry,
     series_frames: List[Saveframe],
-    error_method: ErrorPropogation,
     cycles: int,
     noise_level,
     data_type: IntensityMeasurementType,
@@ -127,6 +112,8 @@ def pipe(
 ) -> Entry:
 
     try:
+        from streamfitter import fitter
+
         if fitter:
             function = fitter.get_function(fitter.FUNCTION_EXPONENTIAL_DECAY_2_PAMETER)
         else:
@@ -145,6 +132,36 @@ def pipe(
             series_frame, NEF_PIPELINES_NAMESPACE, entry
         )
 
+        if noise_level is not None:
+            requested_noise_source = NoiseInfoSource.CLI
+            noise_source = NoiseInfoSource.CLI
+            noise_error_fraction = None
+            num_replicates = None
+        else:
+            requested_noise_source = NoiseInfoSource.REPLICATES
+
+            noise_level, noise_error_fraction, num_replicates = (
+                calculate_noise_level_from_replicates(id_series_data)
+            )
+
+            if noise_level:
+                noise_source = NoiseInfoSource.REPLICATES
+            else:
+                noise_level = None
+                noise_error_fraction = None
+                noise_source = NoiseInfoSource.NONE
+
+        if num_replicates == 0:
+            noise_source = NoiseInfoSource.NONE
+
+        noise_info = NoiseInfo(
+            noise_source,
+            noise_level,
+            noise_error_fraction,
+            num_replicates,
+            requested_noise_source,
+        )
+
         id_xy_data = {
             id: (series_datum.variable_values, series_datum.values)
             for id, series_datum in id_series_data.items()
@@ -153,9 +170,8 @@ def pipe(
         results = fitter.fit(
             function(),
             id_xy_data,
-            error_method,
             cycles,
-            noise_level,
+            noise_info,
             seed,
             verbose=verbose,
         )
@@ -167,16 +183,23 @@ def pipe(
         noise_level = results["noise_level"]
         version_strings = results["versions"]
 
+        fit_name = "time_constant"
+        output = "r1"
+
         frame = _fit_results_as_frame(
             series_frame,
             NEF_PIPELINES_NAMESPACE,
             entry,
             fits,
+            fit_name,
+            output,
             monte_carlo_errors,
             monte_carlo_value_stats,
             monte_carlo_param_values,
-            noise_level,
+            seed,
+            noise_info,
             version_strings,
+            "exponential-decay",
         )
 
         entry.add_saveframe(frame)
