@@ -1,13 +1,14 @@
-import math
 from dataclasses import dataclass, field
 from itertools import combinations
+from math import sqrt
 from statistics import stdev
-from typing import Dict, List, Tuple, Union
+from typing import Dict, List, OrderedDict, Tuple, Union
 
 from fyeah import f
 from ordered_set import OrderedSet
 from pynmrstar import Entry, Loop, Saveframe
 
+from nef_pipelines.lib.interface import NoiseInfo
 from nef_pipelines.lib.isotope_lib import (
     CODE_TO_ISOTOPE,
     GAMMA_RATIOS,
@@ -18,17 +19,52 @@ from nef_pipelines.lib.nef_lib import (
     UNUSED,
     SelectionType,
     create_nef_save_frame,
-    get_frame_id,
     loop_row_namespace_iter,
     select_frames,
 )
 from nef_pipelines.lib.peak_lib import frame_to_peaks
 from nef_pipelines.lib.shift_lib import IntensityMeasurementType
-from nef_pipelines.lib.util import exit_error
+from nef_pipelines.lib.structures import NEFPipelinesException
 
 SERIES_DATA_CATEGORY = "_{NAMESPACE}_series_data"
 
 
+class NEFPLSFitLibException(NEFPipelinesException):
+    """Base exception class for NEF fit library errors."""
+
+    ...
+
+
+class NEFPLSFitLibNoIsotopeFrequenciesError(NEFPLSFitLibException):
+    """Raised when no isotope frequencies are found in spectrum frames."""
+
+    ...
+
+
+class NEFPLSFitLibInconsistentSeriesDataError(NEFPLSFitLibException):
+    """Raised when data is not consistent across series frames (frequencies or isotope axes)."""
+
+    ...
+
+
+class NEFPLSFitLibNoSeriesFramesSelectedError(NEFPLSFitLibException):
+    """Raised when no series frames are selected by the given selectors."""
+
+    ...
+
+
+class NEFPLSFitLibNoFrameSelectorsError(NEFPLSFitLibException):
+    """Raised when no frame selectors are provided."""
+
+    ...
+
+
+class NEFPLSFitLibMissingDataError(NEFPLSFitLibException):
+    """Raised when expected data is missing (series data loop, spectrum frame, or data ID)."""
+
+    ...
+
+
 @dataclass
 class RelaxationSeriesValues:
     spectra: List[str] = field(default_factory=list)
@@ -37,16 +73,63 @@ class RelaxationSeriesValues:
     values: List[Union[int, float, bool]] = field(default_factory=list)
 
 
+def _combine_relaxation_series(
+    series1: RelaxationSeriesValues, series2: RelaxationSeriesValues
+) -> RelaxationSeriesValues:
+    """Combine two RelaxationSeriesValues into a single RelaxationSeriesValues.
+
+    All fields from both series are combined as sequential blocks (series1 data first,
+    then series2 data). Raises an exception if equivalent fields between the two series
+    have different lengths.
+
+    Args:
+        series1: First RelaxationSeriesValues to combine
+        series2: Second RelaxationSeriesValues to combine
+
+    Returns:
+        RelaxationSeriesValues with combined data
+
+    Raises:
+        NEFPLSFitLibInconsistentSeriesDataError: If equivalent fields have different lengths between series
+    """
+    # Validate that equivalent fields between series1 and series2 have the same length
+    field_comparisons = [
+        ("spectra", len(series1.spectra), len(series2.spectra)),
+        ("peak_ids", len(series1.peak_ids), len(series2.peak_ids)),
+        ("variable_values", len(series1.variable_values), len(series2.variable_values)),
+        ("values", len(series1.values), len(series2.values)),
+    ]
+
+    for field_name, len1, len2 in field_comparisons:
+        if len1 != len2:
+            msg = f"Inconsistent field lengths for {field_name}: series1 has {len1}, series2 has {len2}"
+            raise NEFPLSFitLibInconsistentSeriesDataError(msg)
+
+    # Combine all fields as blocks (series1 first, then series2)
+    combined = RelaxationSeriesValues(
+        spectra=[*series1.spectra, *series2.spectra],
+        peak_ids=[*series1.peak_ids, *series2.peak_ids],
+        variable_values=[*series1.variable_values, *series2.variable_values],
+        values=[*series1.values, *series2.values],
+    )
+
+    return combined
+
+
 def _fit_results_as_frame(
     series_frame,
     prefix,
     entry,
     fits,
+    fit_name,
+    output,
     monte_carlo_errors,
     monte_carlo_value_stats,
     monte_carlo_param_values,
-    noise_level,
+    monte_carlo_random_seed,
+    noise_info: NoiseInfo,
     version_strings,
+    fitter_name,
 ):
 
     spectrum_frames = _series_frame_to_spectrum_frames(series_frame, prefix, entry)
@@ -77,11 +160,7 @@ def _fit_results_as_frame(
 
     axis_of_lowest_gamma = _isotope_axes_to_lowest_gamma_axis(isotope_axes)
 
-    frame_id = get_frame_id(series_frame)
-
-    result_frame = create_nef_save_frame(
-        f"{prefix}_relaxation_list", f"{frame_id}_fitted"
-    )
+    result_frame = create_nef_save_frame(f"{prefix}_relaxation_list", output)
 
     result_frame.add_tag("version", NEF_RELAXATION_VERSION)
     result_frame.add_tag("experiment_type", series_frame.get_tag("experiment_type")[0])
@@ -90,16 +169,21 @@ def _fit_results_as_frame(
     result_frame.add_tag("relaxation_atom_id", axis_of_lowest_gamma)
     result_frame.add_tag("ref_value", UNUSED)
     result_frame.add_tag("source", "experimental")
-    result_frame.add_tag("fitting_function", "ExponentialDecay")
+    result_frame.add_tag("fitting_function", fitter_name)
+    # TODO fix this
     result_frame.add_tag("minimizer", "leastsq")
-    result_frame.add_tag("error_method", "montecarlo")
-    comment = f"""
-        fitting software {version_strings}
-        random_seed 42
-        noise_estimate {noise_level}
 
-        source_of_noise_estimate 'replicates'
-        number_of_replicates: {len(spectrum_frames)}
+    result_frame.add_tag("error_method", noise_info.source)
+
+    # TODO move these to tags under nefpls...
+    comment = f"""
+        fitting software: {version_strings}
+        random seed {monte_carlo_random_seed}
+        requested noise estimate source: {noise_info.requested_noise_source}
+        source of noise estimate: {noise_info.source}
+        noise estimate: {noise_info.noise}
+        noise estimate fractional error: {noise_info.fraction_error_in_noise}
+        noise estimate number replicates: {noise_info.num_replicates}
     """
     # error_in_noise-estimate {}
     # fit_time {}
@@ -127,6 +211,8 @@ def _fit_results_as_frame(
 
         peak_atoms = []
         atom_key = next(iter(data_id_to_spectrum_peak_ids[data_id]))
+
+        # TODO check if peak exists or error
         for axis_atoms in spectrum_peak_id_to_axis_atoms[atom_key].values():
             peak_atoms.extend(axis_atoms)
 
@@ -140,14 +226,18 @@ def _fit_results_as_frame(
                     f"atom_name_{i}": atom.atom_name,
                 }
             )
-        data.append(data_row)
-        mc_error = monte_carlo_errors[data_id]["time_constant_mc_error"]
+
+        if monte_carlo_errors:
+            mc_error = monte_carlo_errors[data_id].get(f"{fit_name}_mc_error", UNUSED)
+        else:
+            mc_error = UNUSED
         data_row.update(
             {
-                "value": f'{fit.params["time_constant"].value:.20f}',
-                "value_error": f"{mc_error:.20f}",
+                "value": f"{fit.params[fit_name].value:.6f}",
+                "value_error": f"{mc_error:.6}",
             }
         )
+        data.append(data_row)
 
     relaxation_loop.add_data(data)
 
@@ -194,8 +284,9 @@ def _exit_if_no_frequencies_found(isotope_frequencies, series_frame, entry):
     if not isotope_frequencies:
         msg = f"""
             no isotope frequencies found in the series frame {series_frame.name} in entry {entry.entry_id}
+            this indcates that the series frame is incomplete or missing...
         """
-        exit_error(msg)
+        raise NEFPLSFitLibNoIsotopeFrequenciesError(msg)
 
 
 def _get_unique_isotope_frequencies(isotope_frequencies):
@@ -209,6 +300,7 @@ def _get_unique_isotope_frequencies(isotope_frequencies):
 def _series_frame_to_spectrum_frames(series_frame, prefix, entry):
 
     spectrum_frames = []
+
     for i, row in enumerate(
         loop_row_namespace_iter(
             series_frame.get_loop(f"{prefix}_series_experiment"), convert=True
@@ -255,6 +347,9 @@ def _select_relaxation_series_or_exit(
                 frame_key,
             ]
         )
+    else:
+        # No frame selectors provided and multiple frames available - use all relaxation frames
+        named_frames_and_ids = series_frames_and_ids
 
     selected_frames_and_ids = series_frames_and_ids.intersection(named_frames_and_ids)
 
@@ -272,13 +367,13 @@ def _exit_if_no_series_frames_selected(active_relaxation_frames, frame_selectors
             no series frames selected by the selectors
             {" ".join(frame_selectors)}
         """
-        exit_error(msg)
+        raise NEFPLSFitLibNoSeriesFramesSelectedError(msg)
 
 
 def _exit_if_no_frame_selectors(frame_selectors):
     if len(frame_selectors) == 0:
         msg = "you must select some frames!"
-        exit_error(msg)
+        raise NEFPLSFitLibNoFrameSelectorsError(msg)
 
     return None
 
@@ -296,7 +391,7 @@ def _exit_if_isotope_frequencies_are_not_unique(
                 spectrometer frequencies must be consistent in a series frame
             """
 
-            exit_error(msg)
+            raise NEFPLSFitLibInconsistentSeriesDataError(msg)
 
 
 def _exit_if_isotope_axes_are_not_unique(isotope_axes, series_frame, entry_id):
@@ -311,7 +406,7 @@ def _exit_if_isotope_axes_are_not_unique(isotope_axes, series_frame, entry_id):
                 the axes must be consistent in a series frame
             """
 
-            exit_error(msg)
+            raise NEFPLSFitLibInconsistentSeriesDataError(msg)
 
 
 def spectra_to_isotope_axes(spectrum_frames):
@@ -320,6 +415,7 @@ def spectra_to_isotope_axes(spectrum_frames):
         spectrum_dimension_loop = loop_row_namespace_iter(
             spectrum_frame.get_loop("nef_spectrum_dimension")
         )
+
         for row in spectrum_dimension_loop:
             isotope = CODE_TO_ISOTOPE.get(row.axis_code)
             isotope_axes.setdefault(row.dimension_id, set()).add(isotope)
@@ -359,19 +455,6 @@ def frequencies_to_field_strength(frequencies):
     return fields_by_gamma_and_isotope[highest_gamma_isotope]
 
 
-def orderOfMagnitude(number):
-    return math.floor(math.log(number, 10))
-
-
-# TODO: move to lib
-def get_loop(frame: Saveframe, loop_name: str):
-    try:
-        series_experiment_loop = frame.get_loop(loop_name)
-    except KeyError:
-        series_experiment_loop = None
-    return series_experiment_loop
-
-
 def _get_spectra_by_series_variable(entry, series_experiment_loop):
     from nef_pipelines.lib.nef_lib import loop_row_namespace_iter
 
@@ -390,13 +473,6 @@ def _get_spectra_by_series_variable(entry, series_experiment_loop):
     return spectra_by_times
 
 
-def _exit_if_no_series_data_loops_selected(frame, series_experiment_loop):
-    if not series_experiment_loop:
-        raise Exception()
-        msg = f"no nefpls series data loop found in frame {frame.name}"
-        exit_error(msg)
-
-
 def _exit_if_spectra_are_missing(spectra_by_times_and_indices, series_name):
     for (
         _,
@@ -405,7 +481,7 @@ def _exit_if_spectra_are_missing(spectra_by_times_and_indices, series_name):
     ), spectrum_frame in spectra_by_times_and_indices.items():
         if not spectrum_frame:
             msg = f"no spectrum frame found for series {series_name} for spectrum {spectrum_frame_name}"
-            exit_error(msg)
+            raise NEFPLSFitLibMissingDataError(msg)
 
 
 def _get_atoms_and_values(
@@ -432,13 +508,13 @@ def _get_atoms_and_values(
     return atoms_to_values
 
 
-def _get_noise_from_duplicated_values(xy_data) -> float:
+def calculate_noise_level_from_replicates(xy_data: RelaxationSeriesValues) -> float:
 
     repetitons = []
 
-    for series in xy_data.values():
-        xs = series[0]
-        ys = series[1]
+    for series_values in xy_data.values():
+        xs = series_values.variable_values
+        ys = series_values.values
         ys_by_x = {}
         for x, y in zip(xs, ys):
             ys_by_x.setdefault(float(x), []).append(float(y))
@@ -450,14 +526,34 @@ def _get_noise_from_duplicated_values(xy_data) -> float:
         for combination in combinations(repetiton_set, 2):
             differences.append(combination[0] - combination[1])
 
-    replicates_stdev = stdev(differences) if differences else None
-    replicates_stderr = (
-        replicates_stdev / len(differences) ** 0.5 if differences else None
+    noise_level = stdev(differences) if differences else None
+
+    fraction_error_in_stdev = (
+        1 / sqrt(2) * 1 / sqrt(len(differences)) if differences else None
     )
 
-    stderr_div_stderr = replicates_stderr / replicates_stdev if differences else None
+    return noise_level, fraction_error_in_stdev, len(differences)
 
-    return replicates_stdev, stderr_div_stderr, len(differences)
+
+def _series_frame_to_outputs(series_frame: Saveframe, prefix: str, entry: Entry):
+    NAMESPACE = prefix  # noqa: F841
+    series_category = f(SERIES_DATA_CATEGORY)
+    series_data_loop = (
+        series_frame.get_loop(series_category)
+        if series_category in series_frame
+        else None
+    )
+
+    _exit_if_no_series_data_loop(series_data_loop, series_frame, entry, series_category)
+
+    ids_to_outputs = OrderedDict()
+    for row in loop_row_namespace_iter(series_data_loop):
+
+        data_id = row.data_id
+        if row.relaxation_list_id != UNUSED:
+            ids_to_outputs.setdefault(data_id, OrderedSet()).add(row.relaxation_list_id)
+
+    return ids_to_outputs
 
 
 def _series_frame_to_id_series_data(series_frame: Saveframe, prefix: str, entry: Entry):
@@ -470,24 +566,40 @@ def _series_frame_to_id_series_data(series_frame: Saveframe, prefix: str, entry:
         else None
     )
 
-    _exit_if_no_series_data_loop(series_data_loop, series_frame, entry)
+    _exit_if_no_series_data_loop(series_data_loop, series_frame, entry, series_category)
 
-    id_to_xy_data = {}
+    de_duped_data = OrderedDict()
     for row in loop_row_namespace_iter(series_data_loop):
         data_id = row.data_id
+
+        nmr_spectrum_id = row.nmr_spectrum_id
+        peak_id = row.peak_id
+        variable_value = row.variable_value
+        value = row.value
+
+        values = (nmr_spectrum_id, peak_id, variable_value, value)
+
+        de_duped_data.setdefault(data_id, OrderedSet()).add(values)
+
+    id_to_xy_data = {}
+    for data_id, rows in de_duped_data.items():
         relaxation_series = id_to_xy_data.setdefault(data_id, RelaxationSeriesValues())
-        relaxation_series.spectra.append(row.nmr_spectrum_id)
-        relaxation_series.peak_ids.append(row.peak_id)
-        relaxation_series.variable_values.append(row.variable_value)
-        relaxation_series.values.append(row.value)
+        for row in rows:
+            nmr_spectrum_id, peak_id, variable_value, value = row
+            relaxation_series.spectra.append(nmr_spectrum_id)
+            relaxation_series.peak_ids.append(peak_id)
+            relaxation_series.variable_values.append(variable_value)
+            relaxation_series.values.append(value)
 
     return id_to_xy_data
 
 
-def _exit_if_no_series_data_loop(series_data_loop, series_frame, entry):
-    if not series_data_loop:
+def _exit_if_no_series_data_loop(
+    series_data_loop, series_frame, entry, series_category
+):
+    if series_data_loop is None:
         msg = f"""
-        in the entry {entry.entry_id}
-        the series frame {series_frame.name} does not have a {SERIES_DATA_CATEGORY} loop
+            in the entry {entry.entry_id}
+            the series frame {series_frame.name} does not have a {series_category} loop
         """
-        exit_error(msg)
+        raise NEFPLSFitLibMissingDataError(msg)
