@@ -174,7 +174,7 @@ def unassign(
     input: Path = typer.Option(
         STDIN,
         "-i",
-        "--input",
+        "--in",
         metavar="|PIPE|",
         help="input to read NEF data from [- is stdin]",
     ),
