@@ -1,6 +1,7 @@
 import typer
 
 from nef_pipelines import nef_app
+from nef_pipelines.lib.typer_lib import FilteredHelpGroup
 
 app = typer.Typer()
 export_app = typer.Typer()
@@ -9,15 +10,28 @@ import_app = typer.Typer()
 if nef_app.app:
 
     nef_app.app.add_typer(
-        app, name="mars", help="- read and write mars [shifts and sequences]"
+        app,
+        name="mars",
+        help="- read and write mars [shifts and sequences]",
+        rich_help_panel="Transcoders",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     app.add_typer(
-        export_app, name="export", help="- export mars [shifts and sequences]"
+        export_app,
+        name="export",
+        help="- export mars [shifts and sequences]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     app.add_typer(
-        import_app, name="import", help="- import mars [shifts, sequence & peaks]"
+        import_app,
+        name="import",
+        help="- import mars [shifts, sequence & peaks]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     # import of specific importers must be after app creation to avoid circular imports
