@@ -1,6 +1,7 @@
 import typer
 
 from nef_pipelines import nef_app
+from nef_pipelines.lib.typer_lib import FilteredHelpGroup
 
 app = typer.Typer()
 import_app = typer.Typer()
@@ -12,13 +13,24 @@ if nef_app.app:
         app,
         name="nmrview",
         help="- read and write nmrview [peaks, sequences & shifts]",
+        rich_help_panel="Transcoders",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     app.add_typer(
-        import_app, name="import", help="- import nmrview [peaks, sequences & shifts]"
+        import_app,
+        name="import",
+        help="- import nmrview [peaks, sequences & shifts]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
     app.add_typer(
-        export_app, name="export", help="-  export nmrview [peaks, sequences & shifts]"
+        export_app,
+        name="export",
+        help="-  export nmrview [peaks, sequences & shifts]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     # import of specific importers must be after app creation to avoid circular imports
