@@ -1,6 +1,7 @@
 import typer
 
 from nef_pipelines import nef_app
+from nef_pipelines.lib.typer_lib import FilteredHelpGroup
 
 app = typer.Typer()
 # import_app = typer.Typer()
@@ -8,7 +9,14 @@ export_app = typer.Typer()
 
 if nef_app.app:
 
-    nef_app.app.add_typer(app, name="rpf", help="- write rpf shifts")
+    nef_app.app.add_typer(
+        app,
+        name="rpf",
+        help="- write rpf [shifts]",
+        rich_help_panel="Transcoders",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
+    )
 
     # app.add_typer(import_app, name="import", help="- import fasta sequences")
     app.add_typer(export_app, name="export", help="- export rpf shifts")
