@@ -1,6 +1,7 @@
 import typer
 
 from nef_pipelines import nef_app
+from nef_pipelines.lib.typer_lib import FilteredHelpGroup
 
 app = typer.Typer()
 import_app = typer.Typer()
@@ -13,10 +14,25 @@ if nef_app.app:
         app,
         name="sparky",
         help="- read sparky files [shifts]",
+        rich_help_panel="Transcoders",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
-    app.add_typer(import_app, name="import", help="- import sparky [shifts]")
-    app.add_typer(export_app, name="export", help="- export sparky [peaks]")
+    app.add_typer(
+        import_app,
+        name="import",
+        help="- import sparky [shifts]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
+    )
+    app.add_typer(
+        export_app,
+        name="export",
+        help="- export sparky [peaks]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
+    )
 
     # import of specific importers must be after app creation to avoid circular imports
     import nef_pipelines.transcoders.sparky.exporters.peaks  # noqa: F401
