@@ -10,10 +10,10 @@ from nef_pipelines.lib.nef_lib import (
 )
 from nef_pipelines.lib.sequence_lib import (
     BadResidue,
-    chain_code_iter,
+    get_chain_code_iter,
     get_residue_name_from_lookup,
     sequence_from_entry_or_exit,
-    sequence_to_residue_type_lookup,
+    sequence_to_residue_name_lookup,
     translate_1_to_3,
 )
 from nef_pipelines.lib.shift_lib import shifts_to_nef_frame
@@ -26,7 +26,6 @@ from nef_pipelines.lib.structures import (
 )
 from nef_pipelines.lib.util import (
     STDIN,
-    cached_file_stream,
     exit_error,
     is_int,
     parse_comma_separated_options,
@@ -40,8 +39,6 @@ NUCLEUS = "Nuc"
 
 EXPECTED_HEADINGS = set(f"{GROUP} {ATOM} {NUCLEUS} {SHIFT} SDev Assignments".split())
 
-app = typer.Typer()
-
 
 # noinspection PyUnusedLocal
 @import_app.command(no_args_is_help=True)
@@ -63,26 +60,28 @@ def shifts(
         help="input to read NEF data from [- is stdin]",
     ),
     file_names: List[Path] = typer.Argument(
-        ..., help="input files of type nmrview.out", metavar="<NMRVIEW-shifts>.out"
+        ..., help="input files of type shifts.txt", metavar="<SPARKY-shifts>.txt"
     ),
 ):
-    """convert sparky shift file <sparky-shifts>.txt to NEF"""
+    """- convert sparky shift file <sparky-shifts>.txt to NEF"""
 
     chain_codes = parse_comma_separated_options(chain_codes)
 
     if not chain_codes:
         chain_codes = ["A"]
-
-    _exit_if_chain_codes_and_file_name_dont_match(chain_codes, file_names)
+    elif len(chain_codes) == 1 and len(file_names) > 1:
+        chain_codes = chain_codes * len(file_names)
+    else:
+        _exit_if_number_chain_codes_and_file_names_dont_match(chain_codes, file_names)
 
     entry = read_entry_from_file_or_stdin_or_exit_error(input)
 
-    sequence = sequence_from_entry_or_exit(entry)
+    entry = pipe(entry, chain_codes, frame_name, file_names)
 
-    pipe(entry, chain_codes, sequence, frame_name, file_names)
+    print(entry)
 
 
-def _exit_if_chain_codes_and_file_name_dont_match(chain_codes, file_names):
+def _exit_if_number_chain_codes_and_file_names_dont_match(chain_codes, file_names):
     if len(chain_codes) != len(file_names):
         msg = f"""\
             the number of chains [{len(chain_codes)}] doesn't match the number of files [{len(file_names)}]
@@ -92,27 +91,28 @@ def _exit_if_chain_codes_and_file_name_dont_match(chain_codes, file_names):
         exit_error(msg)
 
 
-def pipe(entry, chain_codes, sequence, entry_name, file_names):
+def pipe(entry, chain_codes, frame_name, file_names):
+
+    sequence = sequence_from_entry_or_exit(entry)
 
     sparky_frames = []
 
-    for file_name, chain_code in zip(file_names, chain_code_iter(chain_codes)):
+    chain_code_iter = get_chain_code_iter(chain_codes)
+    for file_name, chain_code in zip(file_names, chain_code_iter):
 
-        with cached_file_stream(file_name) as lines:
+        with open(file_name) as lines:
 
-            chain_seqid_to_type = sequence_to_residue_type_lookup(sequence)
+            chain_seqid_to_type = sequence_to_residue_name_lookup(sequence)
 
             sparky_shifts = _parse_shifts(
                 lines, chain_seqid_to_type, chain_code=chain_code, file_name=file_name
             )
 
-            frame = shifts_to_nef_frame(sparky_shifts, entry_name)
+            frame = shifts_to_nef_frame(sparky_shifts, frame_name)
 
             sparky_frames.append(frame)
 
-    entry = add_frames_to_entry(entry, sparky_frames)
-
-    print(entry)
+    return add_frames_to_entry(entry, sparky_frames)
 
 
 def _convert_residue_type_to_3_let_or_exit(residue_type, line_info):
