@@ -2,6 +2,7 @@ import typer
 
 import nef_pipelines
 from nef_pipelines import nef_app
+from nef_pipelines.lib.typer_lib import FilteredHelpGroup
 
 app = typer.Typer()
 import_app = typer.Typer()
@@ -11,19 +12,26 @@ if nef_app.app:
     nef_app.app.add_typer(
         app,
         name="xplor",
-        help="- read xplor [sequences, dihedral & distance restraints]",
+        help="- read and write xplor [sequences, dihedral & distance restraints]",
+        rich_help_panel="Transcoders",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     app.add_typer(
         import_app,
         name="import",
         help="- import xplor [sequences, dihedral & distance restraints]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     app.add_typer(
         export_app,
         name="export",
         help="- export xplor [rdcs]",
+        no_args_is_help=True,
+        cls=FilteredHelpGroup,
     )
 
     # import of specific importers must be after app creation to avoid circular imports
